========
Features
========

Docker docker_image Configuration
#################################

- docker_image support docker_extra_options to be passed as a list of arguments to be appended to the docker execution.
